@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2020 the xine project
+ * Copyright (C) 2002-2016 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -34,7 +34,6 @@
 #include "rtsp.h"
 #include "sdpplin.h"
 #include <xine/xineutils.h>
-#include <xine/xine_buffer.h>
 
 static char *nl(char *data) {
 
@@ -65,36 +64,12 @@ static int filter(const char *in, const char *filter, char **out) {
 
   return 0;
 }
-
-static void sdpplin_free_stream(sdpplin_stream_t **pp)
-{
-  if (*pp) {
-    sdpplin_stream_t *p = *pp;
-    _x_freep(&p->id);
-    _x_freep(&p->stream_name);
-    _x_freep(&p->mime_type);
-    _x_freep(&p->mlti_data);
-    _x_freep(&p->asm_rule_book);
-    _x_freep(pp);
-  }
-}
-
 static sdpplin_stream_t *XINE_MALLOC sdpplin_parse_stream(char **data) {
 
-  sdpplin_stream_t *desc;
-  char      *buf;
+  sdpplin_stream_t *desc = calloc(1, sizeof(sdpplin_stream_t));
+  char      *buf=xine_buffer_init(32);
   int       handled;
 
-  desc = calloc(1, sizeof(sdpplin_stream_t));
-  if (!desc)
-    return NULL;
-
-  buf = xine_buffer_init(32);
-  if (!buf) {
-    free(desc);
-    return NULL;
-  }
-
   if (filter(*data, "m=", &buf)) {
     desc->id = strdup(buf);
   } else
@@ -211,6 +186,7 @@ static sdpplin_stream_t *XINE_MALLOC sdpplin_parse_stream(char **data) {
 sdpplin_t *sdpplin_parse(char *data) {
 
   sdpplin_t        *desc = calloc(1, sizeof(sdpplin_t));
+  sdpplin_stream_t *stream;
   char             *buf=xine_buffer_init(32);
   int              handled;
   int              len;
@@ -223,21 +199,16 @@ sdpplin_t *sdpplin_parse(char *data) {
     handled=0;
 
     if (filter(data, "m=", &buf)) {
-      sdpplin_stream_t *stream;
       if ( ! desc->stream ) {
 	fprintf(stderr, "sdpplin.c: stream identifier found before stream count, skipping.");
 	continue;
       }
       stream=sdpplin_parse_stream(&data);
       lprintf("got data for stream id %u\n", stream->stream_id);
-      if ( stream->stream_id >= desc->stream_count ) {
+      if ( stream->stream_id >= desc->stream_count )
 	lprintf("stream id %u is greater than stream count %u\n", stream->stream_id, desc->stream_count);
-        sdpplin_free_stream(&stream);
-      } else {
-        if (desc->stream[stream->stream_id])
-          sdpplin_free_stream(&desc->stream[stream->stream_id]);
-        desc->stream[stream->stream_id]=stream;
-      }
+      else
+	desc->stream[stream->stream_id]=stream;
       continue;
     }
 
@@ -329,21 +300,9 @@ sdpplin_t *sdpplin_parse(char *data) {
   return desc;
 }
 
-void sdpplin_free(sdpplin_t *p) {
+void sdpplin_free(sdpplin_t *description) {
 
-  if (p->stream) {
-    unsigned i;
-    for (i = 0; i < p->stream_count; i++) {
-      sdpplin_free_stream(&p->stream[i]);
-    }
-    _x_freep(&p->stream);
-  }
-
-  _x_freep(&p->title);
-  _x_freep(&p->author);
-  _x_freep(&p->copyright);
-  _x_freep(&p->abstract);
-
-  free(p);
+  /* TODO: free strings */
+  free(description);
 }
 
